==> nats.c_3.7.0.orig.tar.gz: nats.c-3.7.0/doc/html/group__micro_structs.js <==
var group__micro_structs =
[
    [ "micro_endpoint_config_s", "structmicro__endpoint__config__s.html", [
      [ "Name", "structmicro__endpoint__config__s.html#a1a47fe3be59a271217bcb4341cddecae", null ],
      [ "Subject", "structmicro__endpoint__config__s.html#a6c58e0e9c1da670da4a38993a613eb7d", null ],
      [ "Metadata", "structmicro__endpoint__config__s.html#a7aee4ab9e29512c0b6ee12ba233c0fb7", null ],
      [ "Handler", "structmicro__endpoint__config__s.html#a4a916af910a5eb88abf3f0aa60082667", null ],
      [ "State", "structmicro__endpoint__config__s.html#ae9a1cf8dc159a651869e33c1f5cab3eb", null ]
    ] ],
    [ "micro_endpoint_info_s", "structmicro__endpoint__info__s.html", [
      [ "Name", "structmicro__endpoint__info__s.html#ab8b3d1a96e19424fc7f367f2e0dc8175", null ],
      [ "Subject", "structmicro__endpoint__info__s.html#a94d9e2e4c19e17f06c827577cd967502", null ],
      [ "Metadata", "structmicro__endpoint__info__s.html#aef2820ecb742b9ce9a643d39343df740", null ]
    ] ],
    [ "micro_endpoint_stats_s", "structmicro__endpoint__stats__s.html", [
      [ "Name", "structmicro__endpoint__stats__s.html#acfcec95bf83819e8dfe64a4babf62f8e", null ],
      [ "Subject", "structmicro__endpoint__stats__s.html#a08745ca3e151b1d7d5c064659975f4d6", null ],
      [ "NumRequests", "structmicro__endpoint__stats__s.html#a1adfdb3c1641301b419ccf136cbaa927", null ],
      [ "NumErrors", "structmicro__endpoint__stats__s.html#a85ead23cb79aeb6e5c9b4409544412db", null ],
      [ "ProcessingTimeSeconds", "structmicro__endpoint__stats__s.html#a3e971e78657d71f28477476a560162dd", null ],
      [ "ProcessingTimeNanoseconds", "structmicro__endpoint__stats__s.html#a532060ae39ed420c3f84244163b4590b", null ],
      [ "AverageProcessingTimeNanoseconds", "structmicro__endpoint__stats__s.html#acc74c3df96d5f8595521a57dd0eb0cde", null ],
      [ "LastErrorString", "structmicro__endpoint__stats__s.html#a2adef3bbd175d542387fe47b9a156e6c", null ]
    ] ],
    [ "micro_service_config_s", "structmicro__service__config__s.html", [
      [ "Name", "structmicro__service__config__s.html#acb82e165927f5e5c404beb4f3120a8e2", null ],
      [ "Version", "structmicro__service__config__s.html#a20d3780b9452237119aee56853216b03", null ],
      [ "Description", "structmicro__service__config__s.html#a090e884af689503d9c2fcb086a5478e6", null ],
      [ "Metadata", "structmicro__service__config__s.html#a4a5a97a4181a4870353f9e139cca72fc", null ],
      [ "Endpoint", "structmicro__service__config__s.html#ae13d06757417aabf01619090ab83f977", null ],
      [ "StatsHandler", "structmicro__service__config__s.html#a8385ccdaef440f9406a876868663ec56", null ],
      [ "ErrHandler", "structmicro__service__config__s.html#a4069a6987c910fb4f045b233b6befc27", null ],
      [ "DoneHandler", "structmicro__service__config__s.html#ab349d30e0f637d449c0af865234a0985", null ],
      [ "State", "structmicro__service__config__s.html#a0a0ae007824f6f53fbb0cb4b940c5ad2", null ]
    ] ],
    [ "micro_service_info_s", "structmicro__service__info__s.html", [
      [ "Type", "structmicro__service__info__s.html#a47188c4f3a9cc6fdd1151dd59db4b1fe", null ],
      [ "Name", "structmicro__service__info__s.html#a3ac45f2dd5827f95160b1d7899dcf9b7", null ],
      [ "Version", "structmicro__service__info__s.html#a46ad1eddcbed5db1af32add59a910369", null ],
      [ "Description", "structmicro__service__info__s.html#ad1b5706234217f33fdac3435ca920b39", null ],
      [ "Id", "structmicro__service__info__s.html#a9368a61ebb6cf74a27ea261d7517d9c2", null ],
      [ "Metadata", "structmicro__service__info__s.html#a292990d3fd1d94e48fd91e5556a2c091", null ],
      [ "Endpoints", "structmicro__service__info__s.html#ac65a0b0e98971c334080b022f71e482d", null ],
      [ "EndpointsLen", "structmicro__service__info__s.html#afa11d35ca9aa8c19bc95409727479cd7", null ]
    ] ],
    [ "micro_service_stats_s", "structmicro__service__stats__s.html", [
      [ "Type", "structmicro__service__stats__s.html#af37a4da72bb1e1ad292dd1caa6a309a2", null ],
      [ "Name", "structmicro__service__stats__s.html#ae81f531e8fb5f4fe6bba9552743985ca", null ],
      [ "Version", "structmicro__service__stats__s.html#ace4844493f3a27ce7b1accb2d1bb4da5", null ],
      [ "Id", "structmicro__service__stats__s.html#afbc7f9586df0c4d8969736e76284bb20", null ],
      [ "Started", "structmicro__service__stats__s.html#a53e7ea532c4bc4f9a9c4322b28060a4e", null ],
      [ "Endpoints", "structmicro__service__stats__s.html#aa1ac7f9fd93c943ab8619e625976e567", null ],
      [ "EndpointsLen", "structmicro__service__stats__s.html#a88ca92be3498c27f5519c8ddbd2dc9df", null ]
    ] ]
];

==> nats.c_3.10.1.orig.tar.gz: nats.c-3.10.1/doc/html/group__micro_structs.js <==
var group__micro_structs =
[
    [ "micro_endpoint_config_s", "structmicro__endpoint__config__s.html", [
      [ "Name", "structmicro__endpoint__config__s.html#a1a47fe3be59a271217bcb4341cddecae", null ],
      [ "Subject", "structmicro__endpoint__config__s.html#a6c58e0e9c1da670da4a38993a613eb7d", null ],
      [ "QueueGroup", "structmicro__endpoint__config__s.html#abf08a87593d4b7c3d1be7b7392f7fd67", null ],
      [ "NoQueueGroup", "structmicro__endpoint__config__s.html#a920bf9f800a8b46227e4c52272e0c804", null ],
      [ "Metadata", "structmicro__endpoint__config__s.html#a7aee4ab9e29512c0b6ee12ba233c0fb7", null ],
      [ "Handler", "structmicro__endpoint__config__s.html#a4a916af910a5eb88abf3f0aa60082667", null ],
      [ "State", "structmicro__endpoint__config__s.html#ae9a1cf8dc159a651869e33c1f5cab3eb", null ]
    ] ],
    [ "micro_endpoint_info_s", "structmicro__endpoint__info__s.html", [
      [ "Name", "structmicro__endpoint__info__s.html#ab8b3d1a96e19424fc7f367f2e0dc8175", null ],
      [ "Subject", "structmicro__endpoint__info__s.html#a94d9e2e4c19e17f06c827577cd967502", null ],
      [ "QueueGroup", "structmicro__endpoint__info__s.html#ad07fba572478157b89a193ede7297d89", null ],
      [ "Metadata", "structmicro__endpoint__info__s.html#aef2820ecb742b9ce9a643d39343df740", null ]
    ] ],
    [ "micro_endpoint_stats_s", "structmicro__endpoint__stats__s.html", [
      [ "Name", "structmicro__endpoint__stats__s.html#acfcec95bf83819e8dfe64a4babf62f8e", null ],
      [ "Subject", "structmicro__endpoint__stats__s.html#a08745ca3e151b1d7d5c064659975f4d6", null ],
      [ "QueueGroup", "structmicro__endpoint__stats__s.html#a8172de70eeaec314af5728214d9cc230", null ],
      [ "NumRequests", "structmicro__endpoint__stats__s.html#a1adfdb3c1641301b419ccf136cbaa927", null ],
      [ "NumErrors", "structmicro__endpoint__stats__s.html#a85ead23cb79aeb6e5c9b4409544412db", null ],
      [ "ProcessingTimeSeconds", "structmicro__endpoint__stats__s.html#a3e971e78657d71f28477476a560162dd", null ],
      [ "ProcessingTimeNanoseconds", "structmicro__endpoint__stats__s.html#a532060ae39ed420c3f84244163b4590b", null ],
      [ "AverageProcessingTimeNanoseconds", "structmicro__endpoint__stats__s.html#acc74c3df96d5f8595521a57dd0eb0cde", null ],
      [ "LastErrorString", "structmicro__endpoint__stats__s.html#a2adef3bbd175d542387fe47b9a156e6c", null ]
    ] ],
    [ "micro_group_config_s", "structmicro__group__config__s.html", [
      [ "Prefix", "structmicro__group__config__s.html#ac27de1821ea44f444b6061c5bde97bcf", null ],
      [ "QueueGroup", "structmicro__group__config__s.html#a8a59fe960d1a8958807aa0bbc62be033", null ],
      [ "NoQueueGroup", "structmicro__group__config__s.html#a6973fbf91cd9a23446ee4bec98b9830b", null ]
    ] ],
    [ "micro_service_config_s", "structmicro__service__config__s.html", [
      [ "Name", "structmicro__service__config__s.html#acb82e165927f5e5c404beb4f3120a8e2", null ],
      [ "Version", "structmicro__service__config__s.html#a20d3780b9452237119aee56853216b03", null ],
      [ "Description", "structmicro__service__config__s.html#a090e884af689503d9c2fcb086a5478e6", null ],
      [ "QueueGroup", "structmicro__service__config__s.html#abdd93c544c7c368ae4793c4c479afc61", null ],
      [ "NoQueueGroup", "structmicro__service__config__s.html#a78fed3096635174eb037622003661e49", null ],
      [ "Metadata", "structmicro__service__config__s.html#a4a5a97a4181a4870353f9e139cca72fc", null ],
      [ "Endpoint", "structmicro__service__config__s.html#ae13d06757417aabf01619090ab83f977", null ],
      [ "StatsHandler", "structmicro__service__config__s.html#a8385ccdaef440f9406a876868663ec56", null ],
      [ "ErrHandler", "structmicro__service__config__s.html#a4069a6987c910fb4f045b233b6befc27", null ],
      [ "DoneHandler", "structmicro__service__config__s.html#ab349d30e0f637d449c0af865234a0985", null ],
      [ "State", "structmicro__service__config__s.html#a0a0ae007824f6f53fbb0cb4b940c5ad2", null ]
    ] ],
    [ "micro_service_info_s", "structmicro__service__info__s.html", [
      [ "Type", "structmicro__service__info__s.html#a47188c4f3a9cc6fdd1151dd59db4b1fe", null ],
      [ "Name", "structmicro__service__info__s.html#a3ac45f2dd5827f95160b1d7899dcf9b7", null ],
      [ "Version", "structmicro__service__info__s.html#a46ad1eddcbed5db1af32add59a910369", null ],
      [ "Description", "structmicro__service__info__s.html#ad1b5706234217f33fdac3435ca920b39", null ],
      [ "Id", "structmicro__service__info__s.html#a9368a61ebb6cf74a27ea261d7517d9c2", null ],
      [ "Metadata", "structmicro__service__info__s.html#a292990d3fd1d94e48fd91e5556a2c091", null ],
      [ "Endpoints", "structmicro__service__info__s.html#ac65a0b0e98971c334080b022f71e482d", null ],
      [ "EndpointsLen", "structmicro__service__info__s.html#afa11d35ca9aa8c19bc95409727479cd7", null ]
    ] ],
    [ "micro_service_stats_s", "structmicro__service__stats__s.html", [
      [ "Type", "structmicro__service__stats__s.html#af37a4da72bb1e1ad292dd1caa6a309a2", null ],
      [ "Name", "structmicro__service__stats__s.html#ae81f531e8fb5f4fe6bba9552743985ca", null ],
      [ "Version", "structmicro__service__stats__s.html#ace4844493f3a27ce7b1accb2d1bb4da5", null ],
      [ "Id", "structmicro__service__stats__s.html#afbc7f9586df0c4d8969736e76284bb20", null ],
      [ "Started", "structmicro__service__stats__s.html#a53e7ea532c4bc4f9a9c4322b28060a4e", null ],
      [ "Endpoints", "structmicro__service__stats__s.html#aa1ac7f9fd93c943ab8619e625976e567", null ],
      [ "EndpointsLen", "structmicro__service__stats__s.html#a88ca92be3498c27f5519c8ddbd2dc9df", null ]
    ] ]
];
